import * as React from 'react'
import {hot} from 'react-hot-loader'
import data from './data.js';

import {TextAnnotator, TokenAnnotator} from '../../src'

const TEXT = `On Monday night , Mr. Fallon will have a co-host for the first time : The rapper Cardi B , who just released her first album, " Invasion of Privacy . "`

const TAG_COLORS = {
  ORG: '#00ffa2',
  PERSON: '#84d2ff',
  teste: '#111777',
}

const Card = ({children}) => (
  <div
    style={{
      boxShadow: '0 2px 4px rgba(0,0,0,.1)',
      margin: 6,
      maxWidth: 500,
      padding: 16,
    }}
  >
    {children}
  </div>
)

class App extends React.Component<any, any> {
  state = {
    waiting: null,
    value: [{start: 17, end: 19, tag: '', special_label: 'TESTE', color: '#84d2ff'}],
    valueText: [{start: 17, end: 19, tag: 'person', special_label: 'TESTE'}],
    tag: 'reference',
    special_label: 'PERSON',
    wordsToBold: [ 'andrade', 'gutierrez']
  }

  handleChange = response => {
    const { value, waiting } = response;
    this.setState({value, waiting})
  }

  handleChangeText = value => {
    console.log(value, 'oi');
    this.setState({valueText: value})
  }

  handleTagChange = e => {
    this.setState({tag: e.target.value})
  }

  onClickChange = ({start, end}) => {
    console.log(start,end);
  }

  presskey = e => {
    console.log(e.keyCode)
    const { end, start } = this.state.waiting;
    if(this.state.waiting){
      const splitIndex = this.state.value.findIndex(s => s.start === start && s.end === end)
      switch(e.keyCode){
        case 84:
          var value = this.state.value 
          value[splitIndex].tag = 'teste'
          value[splitIndex].special_label = 'teste'
          value[splitIndex].color = TAG_COLORS[value[splitIndex].tag]
          this.setState({ waiting : null, value })

      }
  }
  }

  render() {
    return (
      <div style={{padding: 24, fontFamily: 'IBM Plex Sans'}}>
        <h3 style={{marginTop: 0}}>react-text-annotate</h3>
        <a href="https://github.com/mcamac/react-text-annotate">Github</a>
        <p>A React component for interactively highlighting parts of text.</p>
        <div 
        style={{display: 'flex', marginBottom: 24}}
        tabIndex={0} 
        role="presentation" 
        onKeyDown={e => this.presskey(e)}
        >
          <Card>
            <h4>Default</h4>
            <select onChange={this.handleTagChange} value={this.state.tag}>
              <option value="ORG">ORG</option>
              <option value="PERSON">PERSON</option>
            </select>
            <TokenAnnotator
              waiting={this.state.waiting}
              pre={false}
              style={{
                fontFamily: 'IBM Plex Sans',
                maxWidth: 500,
                lineHeight: 1.5,
              }}
              wordsToBold={this.state.wordsToBold}
              tokens={data.transactions[0].tokenized_text}
              value={this.state.value}
              onChange={this.handleChange}
              onClickChange={this.onClickChange}
              getSpan={span => ({
                ...span,
                tag: this.state.tag,
                special_label: this.state.special_label,
                color: TAG_COLORS[this.state.tag],
              })}
            />
          </Card>
          <Card>
            <h4>Custom rendered mark</h4>
            <select onChange={this.handleTagChange} value={this.state.tag}>
              <option value="ORG">ORG</option>
              <option value="PERSON">PERSON</option>
              <option value="teste">teste</option>
            </select>
            </Card>
            <Card>
            <TextAnnotator
            style={{
              lineHeight: 1.5,
            }}
            content={data.transactions[0].real_text}
            value={this.state.valueText}
            onChange={this.handleChangeText}
            getSpan={span => ({
              ...span,
              tag: this.state.tag,
              special_label: this.state.special_label,
              color: TAG_COLORS[this.state.tag],
            })}
            />
          </Card>
        </div>
        <Card>
          <h4>Current Value</h4>
          <pre>{JSON.stringify(this.state.value, null, 2)}</pre>
          <pre>{JSON.stringify(this.state.valueText, null, 2)}</pre>
        </Card>
      </div>
    )
  }
}

export default hot(module)(App)
